==> deepin-calculator_6.5.16.tar.xz: BUILD/translations/deepin-calculator_zh_HK.ts <==
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE TS>
<TS language="zh_HK" version="2.1">
    <context>
        <name>ExpressionBar</name>
        <message>
            <location filename="../src/widgets/expressionbar.cpp" line="469"/>
            <location filename="../src/widgets/expressionbar.cpp" line="1095"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>IconButton</name>
        <message>
            <location filename="../src/control/iconbutton.cpp" line="110"/>
            <source>Clear all memory</source>
            <translation>清除所有內存</translation>
        </message>
        <message>
            <location filename="../src/control/iconbutton.cpp" line="113"/>
            <source>Clear history</source>
            <translation>清除歷史記錄</translation>
        </message>
    </context>
    <context>
        <name>InputEdit</name>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="298"/>
            <source>Delete</source>
            <translation>刪除</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="299"/>
            <source>Select All</source>
            <translation>全選</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="300"/>
            <source>Use thousands separator</source>
            <translation>切換為千分位</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="301"/>
            <source>Use ten-thousands separator</source>
            <translation>切換為萬分位</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="293"/>
            <source>Undo</source>
            <translation>撤銷</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="294"/>
            <source>Redo</source>
            <translation>恢復</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="295"/>
            <source>Cut</source>
            <translation>剪切</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="296"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="297"/>
            <source>Paste</source>
            <translation>黏貼</translation>
        </message>
    </context>
    <context>
        <name>MainWindow</name>
        <message>
            <location filename="../src/main.cpp" line="104"/>
            <location filename="../src/mainwindow.cpp" line="68"/>
            <source>Calculator</source>
            <translation>計數機</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="44"/>
            <source>Standard</source>
            <translation>標準</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="45"/>
            <source>Scientific</source>
            <translation>科學</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="57"/>
            <source>Mode</source>
            <translation>模式</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="106"/>
            <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
            <translation>計數機是一款簡單易用的桌面計算器，支持標準型、科學型、程式員型模式。</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="46"/>
            <source>Programmer</source>
            <translation>程序員</translation>
        </message>
    </context>
    <context>
        <name>MemoryButton</name>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="103"/>
            <source>Clear memory item</source>
            <translation>清除內存項</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="105"/>
            <source>Clear all memory</source>
            <translation>清除所有內存</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="107"/>
            <source>Memory recall</source>
            <translation>內存重新調用</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="110"/>
            <source>Add to memory item</source>
            <translation>添加到內存項</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="112"/>
            <source>Memory add</source>
            <translation>內存增加</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="115"/>
            <source>Subtract from memory item</source>
            <translation>從內存項中減掉</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="117"/>
            <source>Memory subtract</source>
            <translation>內存減少</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="119"/>
            <source>Memory store</source>
            <translation>內存存儲</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="121"/>
            <source>Memory</source>
            <translation>內存</translation>
        </message>
    </context>
    <context>
        <name>MemoryItemWidget</name>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="147"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="235"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="148"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="236"/>
            <source>Clear memory item</source>
            <translation>清除內存項</translation>
        </message>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="149"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="237"/>
            <source>Add to memory item</source>
            <translation>添加到內存項</translation>
        </message>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="150"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="238"/>
            <source>Subtract from memory item</source>
            <translation>從內存項中減掉</translation>
        </message>
    </context>
    <context>
        <name>MemoryWidget</name>
        <message>
            <location filename="../src/views/memorywidget.cpp" line="102"/>
            <source>Nothing saved in memory</source>
            <translation>內存中沒有數據</translation>
        </message>
    </context>
    <context>
        <name>ProExpressionBar</name>
        <message>
            <location filename="../src/widgets/proexpressionbar.cpp" line="378"/>
            <location filename="../src/widgets/proexpressionbar.cpp" line="434"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>ProListView</name>
        <message>
            <location filename="../src/views/prolistview.cpp" line="36"/>
            <location filename="../src/views/prolistview.cpp" line="52"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
    </context>
    <context>
        <name>ProgramModule</name>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="912"/>
            <source>Arithmetic shift</source>
            <translation>算數移位</translation>
        </message>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="918"/>
            <source>Logical shift</source>
            <translation>邏輯移位</translation>
        </message>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="924"/>
            <source>Circular shift</source>
            <translation>循環移位</translation>
        </message>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="909"/>
            <location filename="../src/widgets/programmodule.cpp" line="930"/>
            <location filename="../src/widgets/programmodule.cpp" line="1406"/>
            <source>Rotate through carry circular shift</source>
            <translation>帶進位循環移位</translation>
        </message>
    </context>
    <context>
        <name>ProgrammerItemWidget</name>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="322"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="341"/>
            <source>Arithmetic shift</source>
            <translation>算數移位</translation>
        </message>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="326"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="345"/>
            <source>Logical shift</source>
            <translation>邏輯移位</translation>
        </message>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="330"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="349"/>
            <source>Circular shift</source>
            <translation>循環移位</translation>
        </message>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="334"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="353"/>
            <source>Rotate through carry circular shift</source>
            <translation>帶進位循環移位</translation>
        </message>
    </context>
    <context>
        <name>QObject</name>
        <message>
            <location filename="../src/main.cpp" line="110"/>
            <source>Calculator</source>
            <translation>計數機</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="143"/>
            <source>Getting theme type settings</source>
            <translation>獲取主題類型設置</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="145"/>
            <source>Current theme type:</source>
            <translation>當前主題類型：</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="147"/>
            <source>Testing translations with longer sentences</source>
            <translation>測試帶有長句子的翻譯</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="148"/>
            <source>This is a calculator application that supports basic arithmetic operations</source>
            <translation>這是一個支持基本算術運算的計算器應用程式</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="149"/>
            <source>Scientific mode provides advanced mathematical functions and constants</source>
            <translation>科學模式提供高級數學函數和常數</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="150"/>
            <source>Programmer mode offers binary, octal, decimal and hexadecimal calculations</source>
            <translation>程式設計師模式提供二進制、八進制、十進制和十六進制計算</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="151"/>
            <source>History view shows all previous calculations and their results</source>
            <translation>歷史視圖顯示所有之前的計算及其結果</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="152"/>
            <source>Memory functions allow you to store and recall calculation results</source>
            <translation>內存功能允許您存儲和調用計算結果</translation>
        </message>
    </context>
    <context>
        <name>SciExpressionBar</name>
        <message>
            <location filename="../src/widgets/sciexpressionbar.cpp" line="501"/>
            <location filename="../src/widgets/sciexpressionbar.cpp" line="547"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>SimpleListDelegate</name>
        <message>
            <location filename="../src/views/simplelistdelegate.cpp" line="188"/>
            <location filename="../src/views/simplelistdelegate.cpp" line="254"/>
            <location filename="../src/views/simplelistdelegate.cpp" line="332"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>SimpleListModel</name>
        <message>
            <location filename="../src/views/simplelistmodel.cpp" line="109"/>
            <source>No history</source>
            <translation>無歷史記錄</translation>
        </message>
    </context>
    <context>
        <name>SimpleListView</name>
        <message>
            <location filename="../src/views/simplelistview.cpp" line="62"/>
            <location filename="../src/views/simplelistview.cpp" line="94"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
        <message>
            <location filename="../src/views/simplelistview.cpp" line="63"/>
            <location filename="../src/views/simplelistview.cpp" line="95"/>
            <source>Delete</source>
            <translation>刪除</translation>
        </message>
    </context>
</TS>

==> deepin-calculator_6.5.29.tar.xz: BUILD/translations/deepin-calculator_zh_HK.ts <==
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE TS>
<TS language="zh_HK" version="2.1">
    <context>
        <name>ExpressionBar</name>
        <message>
            <location filename="../src/widgets/expressionbar.cpp" line="469"/>
            <location filename="../src/widgets/expressionbar.cpp" line="1095"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>IconButton</name>
        <message>
            <location filename="../src/control/iconbutton.cpp" line="110"/>
            <source>Clear all memory</source>
            <translation>清除所有內存</translation>
        </message>
        <message>
            <location filename="../src/control/iconbutton.cpp" line="113"/>
            <source>Clear history</source>
            <translation>清除歷史記錄</translation>
        </message>
    </context>
    <context>
        <name>InputEdit</name>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="298"/>
            <source>Delete</source>
            <translation>刪除</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="299"/>
            <source>Select All</source>
            <translation>全選</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="300"/>
            <source>Use thousands separator</source>
            <translation>切換為千分位</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="301"/>
            <source>Use ten-thousands separator</source>
            <translation>切換為萬分位</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="293"/>
            <source>Undo</source>
            <translation>撤銷</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="294"/>
            <source>Redo</source>
            <translation>恢復</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="295"/>
            <source>Cut</source>
            <translation>剪切</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="296"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
        <message>
            <location filename="../src/widgets/inputedit.cpp" line="297"/>
            <source>Paste</source>
            <translation>黏貼</translation>
        </message>
    </context>
    <context>
        <name>MainWindow</name>
        <message>
            <location filename="../src/main.cpp" line="104"/>
            <location filename="../src/mainwindow.cpp" line="68"/>
            <source>Calculator</source>
            <translation>計算器</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="44"/>
            <source>Standard</source>
            <translation>標準</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="45"/>
            <source>Scientific</source>
            <translation>科學</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="57"/>
            <source>Mode</source>
            <translation>模式</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="106"/>
            <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
            <translation>計算器是一款簡單易用的桌面計算器，支持標準型、科學型、程式員型模式。</translation>
        </message>
        <message>
            <location filename="../src/mainwindow.cpp" line="46"/>
            <source>Programmer</source>
            <translation>程序員</translation>
        </message>
    </context>
    <context>
        <name>MemoryButton</name>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="103"/>
            <source>Clear memory item</source>
            <translation>清除內存項</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="105"/>
            <source>Clear all memory</source>
            <translation>清除所有內存</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="107"/>
            <source>Memory recall</source>
            <translation>內存重新調用</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="110"/>
            <source>Add to memory item</source>
            <translation>添加到內存項</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="112"/>
            <source>Memory add</source>
            <translation>內存增加</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="115"/>
            <source>Subtract from memory item</source>
            <translation>從內存項中減掉</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="117"/>
            <source>Memory subtract</source>
            <translation>內存減少</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="119"/>
            <source>Memory store</source>
            <translation>內存存儲</translation>
        </message>
        <message>
            <location filename="../src/control/memorybutton.cpp" line="121"/>
            <source>Memory</source>
            <translation>內存</translation>
        </message>
    </context>
    <context>
        <name>MemoryItemWidget</name>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="147"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="235"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="148"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="236"/>
            <source>Clear memory item</source>
            <translation>清除內存項</translation>
        </message>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="149"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="237"/>
            <source>Add to memory item</source>
            <translation>添加到內存項</translation>
        </message>
        <message>
            <location filename="../src/views/memoryitemwidget.cpp" line="150"/>
            <location filename="../src/views/memoryitemwidget.cpp" line="238"/>
            <source>Subtract from memory item</source>
            <translation>從內存項中減掉</translation>
        </message>
    </context>
    <context>
        <name>MemoryWidget</name>
        <message>
            <location filename="../src/views/memorywidget.cpp" line="102"/>
            <source>Nothing saved in memory</source>
            <translation>內存中沒有數據</translation>
        </message>
    </context>
    <context>
        <name>ProExpressionBar</name>
        <message>
            <location filename="../src/widgets/proexpressionbar.cpp" line="378"/>
            <location filename="../src/widgets/proexpressionbar.cpp" line="434"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>ProListView</name>
        <message>
            <location filename="../src/views/prolistview.cpp" line="36"/>
            <location filename="../src/views/prolistview.cpp" line="52"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
    </context>
    <context>
        <name>ProgramModule</name>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="912"/>
            <source>Arithmetic shift</source>
            <translation>算數移位</translation>
        </message>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="918"/>
            <source>Logical shift</source>
            <translation>邏輯移位</translation>
        </message>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="924"/>
            <source>Circular shift</source>
            <translation>循環移位</translation>
        </message>
        <message>
            <location filename="../src/widgets/programmodule.cpp" line="909"/>
            <location filename="../src/widgets/programmodule.cpp" line="930"/>
            <location filename="../src/widgets/programmodule.cpp" line="1406"/>
            <source>Rotate through carry circular shift</source>
            <translation>帶進位循環移位</translation>
        </message>
    </context>
    <context>
        <name>ProgrammerItemWidget</name>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="322"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="341"/>
            <source>Arithmetic shift</source>
            <translation>算數移位</translation>
        </message>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="326"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="345"/>
            <source>Logical shift</source>
            <translation>邏輯移位</translation>
        </message>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="330"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="349"/>
            <source>Circular shift</source>
            <translation>循環移位</translation>
        </message>
        <message>
            <location filename="../src/views/programmeritemwidget.cpp" line="334"/>
            <location filename="../src/views/programmeritemwidget.cpp" line="353"/>
            <source>Rotate through carry circular shift</source>
            <translation>帶進位循環移位</translation>
        </message>
    </context>
    <context>
        <name>QObject</name>
        <message>
            <location filename="../src/main.cpp" line="110"/>
            <source>Calculator</source>
            <translation>計算器</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="143"/>
            <source>Getting theme type settings</source>
            <translation>獲取主題類型設置</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="145"/>
            <source>Current theme type:</source>
            <translation>當前主題類型：</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="147"/>
            <source>Testing translations with longer sentences</source>
            <translation>測試帶有長句子的翻譯</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="148"/>
            <source>This is a calculator application that supports basic arithmetic operations</source>
            <translation>這是一個支持基本算術運算的計算器應用程式</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="149"/>
            <source>Scientific mode provides advanced mathematical functions and constants</source>
            <translation>科學模式提供高級數學函數和常數</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="150"/>
            <source>Programmer mode offers binary, octal, decimal and hexadecimal calculations</source>
            <translation>程式設計師模式提供二進制、八進制、十進制和十六進制計算</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="151"/>
            <source>History view shows all previous calculations and their results</source>
            <translation>歷史視圖顯示所有之前的計算及其結果</translation>
        </message>
        <message>
            <location filename="../src/main.cpp" line="152"/>
            <source>Memory functions allow you to store and recall calculation results</source>
            <translation>內存功能允許您存儲和調用計算結果</translation>
        </message>
    </context>
    <context>
        <name>SciExpressionBar</name>
        <message>
            <location filename="../src/widgets/sciexpressionbar.cpp" line="501"/>
            <location filename="../src/widgets/sciexpressionbar.cpp" line="547"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>SimpleListDelegate</name>
        <message>
            <location filename="../src/views/simplelistdelegate.cpp" line="188"/>
            <location filename="../src/views/simplelistdelegate.cpp" line="254"/>
            <location filename="../src/views/simplelistdelegate.cpp" line="332"/>
            <source>Expression error</source>
            <translation>運算式錯誤</translation>
        </message>
    </context>
    <context>
        <name>SimpleListModel</name>
        <message>
            <location filename="../src/views/simplelistmodel.cpp" line="109"/>
            <source>No history</source>
            <translation>無歷史記錄</translation>
        </message>
    </context>
    <context>
        <name>SimpleListView</name>
        <message>
            <location filename="../src/views/simplelistview.cpp" line="62"/>
            <location filename="../src/views/simplelistview.cpp" line="94"/>
            <source>Copy</source>
            <translation>複製</translation>
        </message>
        <message>
            <location filename="../src/views/simplelistview.cpp" line="63"/>
            <location filename="../src/views/simplelistview.cpp" line="95"/>
            <source>Delete</source>
            <translation>刪除</translation>
        </message>
    </context>
</TS>
